@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: admin.py 11569 2019-05-21 20:41:08Z Lavender $
+# $Id: admin.py 11589 2019-05-28 17:47:23Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-05-22 05:41:08 +0900 (週三, 22 五月 2019) $
-# $Revision: 11569 $
+# $Date: 2019-05-29 02:47:23 +0900 (週三, 29 五月 2019) $
+# $Revision: 11589 $
 
 import urllib
 import re
@@ -36,13 +36,7 @@ from djangocms_text_ckeditor.models import Text
 from taggit import models
 from awesome_slugify import Slugify
 
-from Iuppiter.Encoding import utf8
-
 from Zephyrus.blog_extension import views
-from Zephyrus.blog_extension.models import Statistics, ViewCount
-from Zephyrus.comment.models import CommentConfig, Comment
-from Zephyrus.facebook.models import ShareLike
-from Zephyrus.facebook.templatetags.Facebook import getApiData
 
 unicodeSlugify = Slugify(translate=None)
 
@@ -243,60 +237,4 @@ class CategoryAdmin2(CategoryAdmin):
 admin.site.unregister(Category)
 admin.site.register(Category, CategoryAdmin2)
 
-# blog_extension
-@admin.register(Statistics)
-class StatisticsAdmin(admin.ModelAdmin):
-    model = Statistics
-
-    list_display = ['getUrl', 'viewCount', 'likeCount', 'commentCount']
-
-    def get_queryset(self, request):
-    
-        @transaction.atomic
-        def updateData():
-            for vc in ViewCount.objects.all():
-                url = vc.url
-                
-                # viewCount
-                obj, created = Statistics.objects.get_or_create(
-                    url=url
-                )
-                obj.viewCount = vc.count
-                
-                # likeCount
-                likeCount = getApiData(url, "share_count")
-                if likeCount:
-                    obj.likeCount = likeCount
-                
-                # commentCount
-                config, created = CommentConfig.objects.get_or_create(
-                    url=url,
-                    defaults={'useFbComment': False},
-                )
-                if config.useFbComment:
-                    commentCount = getApiData(url, "comment_count")
-                    if commentCount:
-                        obj.commentCount = commentCount
-                else:
-                    obj.commentCount = Comment.objects.filter(
-                                        url=url, display=True).count()
-                obj.save()
-                
-        updateData()
-        
-        return super(StatisticsAdmin, self).get_queryset(request)
-
-    def getUrl(self, obj):
-        if six.PY3:
-            name = urllib.parse.unquote(str(obj.url))
-        else:
-            name = urllib.unquote(str(obj.url))
-            
-        name = utf8(name).decode('utf8')
-         
-        return u"<a target='_blank' href='%s'>%s</a>" % (obj.url, name)
-
-    getUrl.short_description = "URL"
-    getUrl.admin_order_field = 'url'
-    getUrl.allow_tags = True
 
