@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: cms_plugins.py 11234 2018-09-29 12:58:04Z Lavender $
+# $Id: cms_plugins.py 11590 2019-05-28 18:28:03Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2018-09-29 21:58:04 +0900 (週六, 29 九月 2018) $
-# $Revision: 11234 $
+# $Date: 2019-05-29 03:28:03 +0900 (週三, 29 五月 2019) $
+# $Revision: 11590 $
 
 import datetime
 
@@ -139,7 +139,7 @@ class FilterArticlePlugin(CMSPluginBase):
             articles = queryset
 
         context.update({
-            'articles': queryset,
+            'articles': articles,
         })
         return context
 
