@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11593 2019-05-29 06:23:49Z Lavender $
+# $Id: models.py 11601 2019-06-01 19:27:05Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-05-29 15:23:49 +0900 (週三, 29 五月 2019) $
-# $Revision: 11593 $
+# $Date: 2019-06-02 04:27:05 +0900 (週日, 02 六月 2019) $
+# $Revision: 11601 $
 
 import datetime
 
@@ -60,21 +60,31 @@ class RecentResponsePlugin(CMSPlugin):
     )
 
 class Comment(models.Model):
-    url = models.CharField(max_length=400, editable=False, null=True)
+    url = models.CharField(
+        verbose_name=_("URL"), max_length=400, editable=False, null=True)
     
-    user = models.ForeignKey(settings.AUTH_USER_MODEL, null=True, blank=True)
-    email = models.EmailField(max_length=254, null=True, blank=True)
+    user = models.ForeignKey(
+        settings.AUTH_USER_MODEL, null=True, blank=True, verbose_name=_("User"),)
+    email = models.EmailField(
+        verbose_name=_("Email"), max_length=254, null=True, blank=True)
     
-    message = models.TextField()
+    message = models.TextField(verbose_name=_("Message"))
 
-    createDate = models.DateTimeField(auto_now_add=True)
-    display = models.BooleanField(default=True)
+    createDate = models.DateTimeField(
+        verbose_name=_("Create date"), auto_now_add=True)
+    display = models.BooleanField(verbose_name=_("Display"), default=True)
 
-    facebook = models.BooleanField(default=False)
-    facebookUser = models.CharField(max_length=128, editable=False, null=True)
+    facebook = models.BooleanField(
+        verbose_name=_("Is Facebook comment plugin"), default=False)
+    facebookMsgId = models.CharField(
+        verbose_name=_("Facebook comment Id"), max_length=400, 
+        editable=False, null=True)
+    facebookUser = models.CharField(
+        verbose_name=_("Facebook user"), 
+        max_length=128, editable=False, null=True)
     
     @property
-    def username(self):
+    def userName(self):
         if not self.facebook:
             if self.user:
                 return self.user.username
@@ -83,6 +93,13 @@ class Comment(models.Model):
         else:
             return self.facebookUser
 
+    def __unicode__(self):
+        return u"<Comment %d: %s>" % (self.id, self.url)
+
+    class Meta:
+        verbose_name = _("Comment")
+        verbose_name_plural = _("Comments")
+
 
 class CommentConfig(models.Model):
     url = models.CharField(max_length=400, editable=False, null=True)
