@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 11593 2019-05-29 06:23:49Z Lavender $
+# $Id: __init__.py 11601 2019-06-01 19:27:05Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,16 +12,26 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-05-29 15:23:49 +0900 (週三, 29 五月 2019) $
-# $Revision: 11593 $
+# $Date: 2019-06-02 04:27:05 +0900 (週日, 02 六月 2019) $
+# $Revision: 11601 $
 
 import json
 import requests
+import urllib
 
+import six
+
+from django.utils.http import urlquote
 from django.conf import settings as _settings
 from django.utils.translation import ugettext_lazy as _
 
-class settings(object):
+if six.PY3:
+    from urllib.parse import urlparse
+else:
+    from urlparse import urlparse
+
+class Settings(object):
+    # Facebook Nuwa Blog APP
     ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID = "1435073943305111"
     ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET = "1f0ba7a626695ee0c5419627c2d0a8b9"
     ZEPHYRUS_FACEBOOK_WEBHOOK_VERIFY_TOKEN = "25025529"
@@ -49,6 +59,8 @@ class settings(object):
             if not ele[0] == "facebook/FacebookPhotoPlugin.html":
                 ZEPHYRUS_FACEBOOK_PHOTO_TEMPLATES.append(ele)
 
+settings = Settings()
+
 def getCommentURL(commentId, 
     key=settings.ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID, 
     value=settings.ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET):
@@ -62,7 +74,35 @@ def getCommentURL(commentId,
     url = data.get("permalink_url")
 
     if url:
-        return url[:url.index("?")]
+        url = urlparse(url)
+        return "%s://%s%s" % (url.scheme, url.netloc, url.path)
     else:
         return None
 
+def getAPIData(url, fieldName, 
+    key=settings.ZEPHYRUS_FACEBOOK_DEFAULT_APP_ID, 
+    value=settings.ZEPHYRUS_FACEBOOK_DEFAULT_APP_SECRET):
+
+    accessToken = '%s|%s' % (key, value)
+    
+    apiUrl = (
+        'https://graph.facebook.com/v3.3/'
+        '?id=%s&fields=engagement&access_token=%s' % (
+        urlquote(url), accessToken)
+    )
+    data = json.loads(requests.get(apiUrl).text)
+    if fieldName == "comment_count":
+        # comment_plugin_count
+        fieldName = "comment_plugin_count"
+        return data.get("engagement", {}).get(fieldName, None)
+    if fieldName == "share_count":
+        # like
+        fieldName = 'reaction_count'
+        reaction = data.get("engagement", {}).get(fieldName, 0)
+        fieldName = "comment_count"
+        comment = data.get("engagement", {}).get(fieldName, 0)
+        fieldName = 'share_count'
+        share = data.get("engagement", {}).get(fieldName, 0)
+        return reaction + share + comment
+    return data.get("engagement", {}).get(fieldName, None)
+
