@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: models.py 11590 2019-05-28 18:28:03Z Lavender $
+# $Id: models.py 11599 2019-06-01 18:56:30Z Lavender $
 #
 # Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2019-05-29 03:28:03 +0900 (週三, 29 五月 2019) $
-# $Revision: 11590 $
+# $Date: 2019-06-02 03:56:30 +0900 (週日, 02 六月 2019) $
+# $Revision: 11599 $
 
 from django.db import models
 from django.utils.translation import ugettext_lazy as _
@@ -48,6 +48,10 @@ class FacebookFan(CMSPlugin):
 
     onlyMessageDisplay = models.BooleanField(
         _('Only display article has message'), default=True)
+
+    class Meta:
+        verbose_name = _("Facebook Fan Page")
+        verbose_name_plural = _("Facebook Fan Page")
     
 class FacebookPhoto(CMSPlugin):
     url = models.URLField()
@@ -59,6 +63,10 @@ class FacebookPhoto(CMSPlugin):
         default=settings.ZEPHYRUS_FACEBOOK_PHOTO_DEFAULT_TEMPLATE,
     )
 
+    class Meta:
+        verbose_name = _("Facebook Fan Photo")
+        verbose_name_plural = _("Facebook Fan Photo")
+
 LAYOUT_CHOICE = (
     ('standard',  _("Standard")),
     ('button_count',  _("Button Count")),
