@@ -26,3 +26,7 @@ class URL(models.Model):
         verbose_name=_("Like count"), default=0)
     commentCount = models.PositiveIntegerField(
         verbose_name=_("Comment count"), default=0)
+
+    class Meta:
+        verbose_name = _("URL")
+        verbose_name_plural = _("URLs")
