@@ -17,10 +17,7 @@ from django.contrib import admin
 from django.conf.urls.static import static
 from django.conf import settings
 
-from main import views as mainViews
-
 urlpatterns = [
     url(r'^admin/', include(admin.site.urls)),
-    url(r'^email/', mainViews.EmailView.as_view(), name='email'),
     url(r'^', include('cms.urls')),
 ] + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
